<?php
// 画像サムネイル作成リクエスト処理

// 前処理
session_start();
require_once('./include.php');

// GET メソッドの場合
if ($_SERVER['REQUEST_METHOD'] == 'GET') {
  output_image();
}

// POST メソッドの場合
// 変数初期化
$output = './thumbnail.php';
$alt = './noimage.png'; // 画像ファイルが存在しない場合の代替画像
$uri = FALSE;
if (isset($_SESSION['uri'])) $uri = $_SESSION['uri'];

// リクエストパラメータの取得と正規化
import_request_variables('p', 'req_');
$len = $req_l;
if ($len < $min) $len = $min;
if ($len > $max) $len = $max;
$idx = $req_i;
if ($idx <= 0) $idx = 1;
$pag = $req_n;
$brd = $req_b;
if ($brd == 1) $brd ='black';
$sdw = $req_s;
if ($sdw == 1) $sdw ='black';
$so = $req_so;
if ($so < 0) $so = 0;
if ($so > 100) $so = 100;
$ss = $req_ss;
if ($ss < 0) $ss = 0;
if ($ss > 10) $ss =10;
$bg = $req_bg;
if ($bg == '') $bg = 'transparent';
$url = $req_url;

// アップロードファイルのチェック
$file = $_FILES['upfile']['tmp_name'];
if (is_uploaded_file($file)) {
  $size = filesize($file);
  if ($size < 100 || $size > $maxfile * 1024 *1024) {
    $file = '';
  } else {
    $url = $_FILES['upfile']['name'];
  }
} else {
  $file = '';
}

// 画像の読み込み
if ($url !== $uri) {
  $src = new Imagick();
  $src->setSize($max, $max);
  try {
    if ($file) {
      $src->readImageBlob(@file_get_contents($file));
    } else {
      $src->readImageBlob(@file_get_contents($url));
    }
  } catch(Exception $e) {
    $src->readImage($url = $alt);
  }
  $src->setImageFormat('png');
  $_SESSION['img'] = $src->getImagesBlob();
  $_SESSION['uri'] = $url;
}

// ImageMagick オブジェクト作成
if (!isset($src)) {
  $src = new Imagick();
  $src->setSize($max, $max);
  $src->readImageBlob($_SESSION['img']);
}
$dst = new Imagick();
$out = new Imagick();

// 変換ページの設定
$n = $src->getNumberImages();
if ($pag <= 0) $pag = $n;
if ($idx > $n) $idx = $n;
$idx--;
$last = $idx + $pag;
if ($last > $n) $last = $n;

for($i = $idx; $i < $last; $i++) {
  // 処理ページ設定
  $src->setIteratorIndex($i);
  $src->setImageFormat('png');

  // 画像をサムネイル化
  $w = $src->getImageWidth();
  $h = $src->getImageHeight();
  if ($h > $len || $w > $len) {
    if ($h > $w) {
      $src->thumbnailImage(0, $len);
    } else {
      $src->thumbnailImage($len, 0);
    }
  }

  // b パラメータが存在すれば、枠線を付ける
  if ($brd) {
    try {
      $src->borderImage($brd, 1, 1);
    } catch(Exception $e) {
      $src->borderImage('black', 1, 1);
    }
  }

  // s パラメータが存在すれば、影を付ける
  $dst->clear();
  $dst->readImageBlob($src->getImageBlob()); // PDF ファイルの影が意図通りに表示されない対策
  if ($sdw) {
    try {
      $dst->setImageBackgroundColor($sdw);
    } catch(Exception $e) {
      $dst->setImageBackgroundColor($bg);
    }
    $dst->shadowImage($so, $len * $ss / 100, 0, 0);
    $dst->setImageBackgroundColor('white');
    $dst->compositeImage($src, Imagick::COMPOSITE_OVER, 0, 0);
  }

  // サムネイルを出力バッファに追加
  $out->addImage($dst);
}

// 画像をひとつにまとめてセッションデータに保存
$out->resetIterator();
$out->setImageFormat('png');
$_SESSION['thumb'] = $out->appendImages(FALSE)->getImageBlob();

// 画像ダイレクト出力の場合
if ($req_typ == 'image') {
  // IE でこのスクリプトから image/png を出力すると BMP でしか保存できない対策
  if (preg_match('/\s+MSIE/', $_SERVER['HTTP_USER_AGENT'])) {
    header('Location: ./thumbnail.php');
    exit;
  }
  output_image();
}

// HTML 経由出力の場合
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
<meta http-equiv="Content-Style-Type" content="text/css" />
<meta http-equiv="Content-Script-Type" content="text/javascript" />
<script type="text/javascript">
<!--
function refresh() {
    window.location.reload("true");
}
//-->
</script>
<title>Thumbnail</title>
<link href="./style.css" rel="stylesheet" type="text/css" />
</head>
<body bgcolor="<?php echo $bg; ?>">
<div class="image">
<?php
if ($req_tag == 'img') {
  echo "<img src=\"$output\" alt=\"Thumbnail\" />";
} else {
  echo "<object data=\"$output\" type=\"image/png\">Thumbnail</object>";
}
?>
<!--<p><input type="button" value="更新" class="button" onclick="refresh()" /></p>-->
</div>
</body>
</html>
